@@ -106,12 +106,11 @@ class CombustionChamberStoich(CombustionChamber):
     path : str
         Path to existing fluid property table.
 
-    lamb : float, tespy.tools.data_containers.ComponentProperties
+    lamb : float, dict
         Air to stoichiometric air ratio, :math:`\lambda/1`.
 
-    ti : float, tespy.tools.data_containers.ComponentProperties
-        Thermal input, (:math:`{LHV \cdot \dot{m}_f}`),
-        :math:`ti/\text{W}`.
+    ti : float, dict
+        Thermal input, (:math:`{LHV \cdot \dot{m}_f}`), :math:`ti/\text{W}`.
 
     Note
     ----
@@ -346,7 +345,7 @@ class CombustionChamberStoich(CombustionChamber):
 
                 n = {}
                 for el in ['C', 'H', 'O']:
-                    if el in structure.keys():
+                    if el in structure:
                         n[el] = structure[el]
                     else:
                         n[el] = 0
@@ -436,7 +435,7 @@ class CombustionChamberStoich(CombustionChamber):
                     set([a.replace(' ', '') for a in CP.get_aliases(f)]))
 
             if len(fl) == 0:
-                if f in self.fg.keys():
+                if f in self.fg:
                     self.fg[f] += x * m_fuel
                 else:
                     self.fg[f] = x * m_fuel
@@ -446,7 +445,7 @@ class CombustionChamberStoich(CombustionChamber):
                 structure = fluid_structure(f)
                 n = {}
                 for el in ['C', 'H', 'O']:
-                    if el in structure.keys():
+                    if el in structure:
                         n[el] = structure[el]
                     else:
                         n[el] = 0
@@ -465,7 +464,7 @@ class CombustionChamberStoich(CombustionChamber):
 
         for f, x in self.air.val.items():
             if f != self.o2:
-                if f in self.fg.keys():
+                if f in self.fg:
                     self.fg[f] += m_air * x
                 else:
                     self.fg[f] = m_air * x
