@@ -362,7 +362,7 @@ class Memorise:
             logging.debug(msg)
 
         for f, back_end in fluids.items():
-            if f not in Memorise.state.keys() and back_end != 'TESPy':
+            if f not in Memorise.state and back_end != 'TESPy':
                 # create CoolProp.AbstractState object
                 try:
                     Memorise.state[f] = CP.AbstractState(back_end, f)
@@ -525,7 +525,7 @@ def T_mix_ph(flow, T0=300):
     """
     # check if fluid properties have been calculated before
     fl = tuple(flow[3].keys())
-    memorisation = fl in Memorise.T_ph.keys()
+    memorisation = fl in Memorise.T_ph
     if memorisation:
         a = Memorise.T_ph[fl][:, :-2]
         b = np.array([flow[1], flow[2]] + list(flow[3].values()))
@@ -581,7 +581,7 @@ def T_ph(p, h, fluid):
     T : float
         Temperature T / K.
     """
-    if fluid in TESPyFluid.fluids.keys():
+    if fluid in TESPyFluid.fluids:
         db = TESPyFluid.fluids[fluid].funcs['h_pT']
         return newton(reverse_2d, reverse_2d_deriv, [db, p, h], 0)
     elif Memorise.back_end[fluid] == 'IF97':
@@ -726,7 +726,7 @@ def T_mix_ps(flow, s, T0=300):
     """
     # check if fluid properties have been calculated before
     fl = tuple(flow[3].keys())
-    memorisation = fl in Memorise.T_ps.keys()
+    memorisation = fl in Memorise.T_ps
     if memorisation:
         a = Memorise.T_ps[fl][:, :-2]
         b = np.asarray([flow[1], flow[2]] + list(flow[3].values()) + [s])
@@ -782,7 +782,7 @@ def T_ps(p, s, fluid):
     T : float
        Temperature T / K.
     """
-    if fluid in TESPyFluid.fluids.keys():
+    if fluid in TESPyFluid.fluids:
         db = TESPyFluid.fluids[fluid].funcs['s_pT']
         return newton(reverse_2d, reverse_2d_deriv, [db, p, s], 0)
     else:
@@ -851,11 +851,11 @@ def h_pT(p, T, fluid, force_gas=False):
     h : float
         Specific enthalpy h / (J/kg).
     """
-    if fluid in TESPyFluid.fluids.keys():
+    if fluid in TESPyFluid.fluids:
         return TESPyFluid.fluids[fluid].funcs['h_pT'].ev(p, T)
     else:
         if force_gas:
-            if T < Memorise.state[fluid].trivial_keyed_output(CP.iT_critical):
+            if T < get_T_crit(fluid):
                 Memorise.state[fluid].update(CP.PT_INPUTS, p, T)
                 h = Memorise.state[fluid].hmass()
                 Memorise.state[fluid].update(CP.QT_INPUTS, 1, T)
@@ -944,7 +944,7 @@ def h_ps(p, s, fluid):
     h : float
         Specific enthalpy h / (J/kg).
     """
-    if fluid in TESPyFluid.fluids.keys():
+    if fluid in TESPyFluid.fluids:
         db = TESPyFluid.fluids[fluid].funcs['s_pT']
         T = newton(reverse_2d, reverse_2d_deriv, [db, p, s], 0)
         return TESPyFluid.fluids[fluid].funcs['h_pT'].ev(p, T)
@@ -1041,8 +1041,8 @@ def h_mix_pQ(flow, Q):
     try:
         Memorise.state[fluid].update(CP.PQ_INPUTS, flow[1], Q)
     except ValueError:
-        pcrit = Memorise.state[fluid].trivial_keyed_output(CP.iP_critical)
-        Memorise.state[fluid].update(CP.PQ_INPUTS, pcrit * 0.99, Q)
+        p_crit = get_p_crit(fluid)
+        Memorise.state[fluid].update(CP.PQ_INPUTS, p_crit * 0.99, Q)
 
     return Memorise.state[fluid].hmass()
 
@@ -1083,7 +1083,39 @@ def dh_mix_dpQ(flow, Q):
     lo[1] -= d
     return (h_mix_pQ(up, Q) - h_mix_pQ(lo, Q)) / (2 * d)
 
-# %%
+
+def get_p_crit(fluid):
+    """
+    Get critical point pressure.
+
+    Parameters
+    ----------
+    fluid : str
+        Fluid name.
+
+    Returns
+    -------
+    p_crit : float
+        Critical point pressure.
+    """
+    return Memorise.state[fluid].trivial_keyed_output(CP.iP_critical)
+
+
+def get_T_crit(fluid):
+    """
+    Get critical point temperature.
+
+    Parameters
+    ----------
+    fluid : str
+        Fluid name.
+
+    Returns
+    -------
+    T_crit : float
+        Critical point temperature.
+    """
+    return Memorise.state[fluid].trivial_keyed_output(CP.iT_critical)
 
 
 def T_bp_p(flow):
@@ -1106,9 +1138,9 @@ def T_bp_p(flow):
     This function works for pure fluids only!
     """
     fluid = single_fluid(flow[3])
-    pcrit = Memorise.state[fluid].trivial_keyed_output(CP.iP_critical)
-    if flow[1] > pcrit:
-        Memorise.state[fluid].update(CP.PQ_INPUTS, pcrit * 0.99, 1)
+    p_crit = get_p_crit(fluid)
+    if flow[1] > p_crit:
+        Memorise.state[fluid].update(CP.PQ_INPUTS, p_crit * 0.99, 1)
     else:
         Memorise.state[fluid].update(CP.PQ_INPUTS, flow[1], 1)
     return Memorise.state[fluid].T()
@@ -1178,7 +1210,7 @@ def v_mix_ph(flow, T0=300):
     """
     # check if fluid properties have been calculated before
     fl = tuple(flow[3].keys())
-    memorisation = fl in Memorise.v_ph.keys()
+    memorisation = fl in Memorise.v_ph
     if memorisation:
         a = Memorise.v_ph[fl][:, :-2]
         b = np.asarray([flow[1], flow[2]] + list(flow[3].values()))
@@ -1226,7 +1258,7 @@ def d_ph(p, h, fluid):
     d : float
         Density d / (kg/:math:`\mathrm{m}^3`).
     """
-    if fluid in TESPyFluid.fluids.keys():
+    if fluid in TESPyFluid.fluids:
         db = TESPyFluid.fluids[fluid].funcs['h_pT']
         T = newton(reverse_2d, reverse_2d_deriv, [db, p, h], 0)
         return TESPyFluid.fluids[fluid].funcs['d_pT'].ev(p, T)
@@ -1416,7 +1448,7 @@ def d_pT(p, T, fluid):
     d : float
         Density d / (kg/:math:`\mathrm{m}^3`).
     """
-    if fluid in TESPyFluid.fluids.keys():
+    if fluid in TESPyFluid.fluids:
         return TESPyFluid.fluids[fluid].funcs['d_pT'].ev(p, T)
     else:
         Memorise.state[fluid].update(CP.PT_INPUTS, p, T)
@@ -1454,7 +1486,7 @@ def visc_mix_ph(flow, T0=300):
     """
     # check if fluid properties have been calculated before
     fl = tuple(flow[3].keys())
-    memorisation = fl in Memorise.visc_ph.keys()
+    memorisation = fl in Memorise.visc_ph
     if memorisation:
         a = Memorise.visc_ph[fl][:, :-2]
         b = np.asarray([flow[1], flow[2]] + list(flow[3].values()))
@@ -1501,7 +1533,7 @@ def visc_ph(p, h, fluid):
     visc : float
         Viscosity visc / Pa s.
     """
-    if fluid in TESPyFluid.fluids.keys():
+    if fluid in TESPyFluid.fluids:
         db = TESPyFluid.fluids[fluid].funcs['h_pT']
         T = newton(reverse_2d, reverse_2d_deriv, [db, p, h], 0)
         return TESPyFluid.fluids[fluid].funcs['visc_pT'].ev(p, T)
@@ -1580,7 +1612,7 @@ def visc_pT(p, T, fluid):
     visc : float
         Viscosity visc / Pa s.
     """
-    if fluid in TESPyFluid.fluids.keys():
+    if fluid in TESPyFluid.fluids:
         return TESPyFluid.fluids[fluid].funcs['visc_pT'].ev(p, T)
     else:
         Memorise.state[fluid].update(CP.PT_INPUTS, p, T)
@@ -1618,7 +1650,7 @@ def s_mix_ph(flow, T0=300):
     """
     # check if fluid properties have been calculated before
     fl = tuple(flow[3].keys())
-    memorisation = fl in Memorise.s_ph.keys()
+    memorisation = fl in Memorise.s_ph
     if memorisation:
         a = Memorise.s_ph[fl][:, :-2]
         b = np.asarray([flow[1], flow[2]] + list(flow[3].values()))
@@ -1666,7 +1698,7 @@ def s_ph(p, h, fluid):
     s : float
         Specific entropy s / (J/(kgK)).
     """
-    if fluid in TESPyFluid.fluids.keys():
+    if fluid in TESPyFluid.fluids:
         db = TESPyFluid.fluids[fluid].funcs['h_pT']
         T = newton(reverse_2d, reverse_2d_deriv, [db, p, h], 0)
         return TESPyFluid.fluids[fluid].funcs['s_pT'].ev(p, T)
@@ -1714,17 +1746,17 @@ def s_mix_pT(flow, T, force_gas=False):
     fluid_comps = {}
 
     tespy_fluids = [
-        s for s in flow[3].keys() if s in TESPyFluid.fluids.keys()]
+        s for s in flow[3].keys() if s in TESPyFluid.fluids]
     for f in tespy_fluids:
         for it, x in TESPyFluid.fluids[f].fluid.items():
-            if it in fluid_comps.keys():
+            if it in fluid_comps:
                 fluid_comps[it] += x * flow[3][f]
             else:
                 fluid_comps[it] = x * flow[3][f]
 
-    fluids = [s for s in flow[3].keys() if s not in TESPyFluid.fluids.keys()]
+    fluids = [s for s in flow[3].keys() if s not in TESPyFluid.fluids]
     for f in fluids:
-        if f in fluid_comps.keys():
+        if f in fluid_comps:
             fluid_comps[f] += flow[3][f]
         else:
             fluid_comps[f] = flow[3][f]
@@ -1762,11 +1794,11 @@ def s_pT(p, T, fluid, force_gas):
     s : float
         Specific entropy s / (J/(kgK)).
     """
-    if fluid in TESPyFluid.fluids.keys():
+    if fluid in TESPyFluid.fluids:
         return TESPyFluid.fluids[fluid].funcs['s_pT'].ev(p, T)
     else:
         if force_gas:
-            if T < Memorise.state[fluid].trivial_keyed_output(CP.iT_critical):
+            if T < get_T_crit(fluid):
                 Memorise.state[fluid].update(CP.PT_INPUTS, p, T)
                 s = Memorise.state[fluid].smass()
                 Memorise.state[fluid].update(CP.QT_INPUTS, 1, T)
@@ -1846,7 +1878,7 @@ def calc_physical_exergy(conn, p0, T0):
     Calculate specific physical exergy.
 
     Physical exergy is allocated to a thermal and a mechanical share according
-    to :cite:`Morosuk2005`.
+    to :cite:`Morosuk2019`.
 
     Parameters
     ----------
@@ -1886,7 +1918,7 @@ def calc_physical_exergy(conn, p0, T0):
 
 def entropy_iteration_IF97(p, h, fluid, output):
     r"""
-    Generate the state of IF97::water via entropy iteration.
+    Calculate state in IF97 back-end via entropy iteration.
 
     Parameters
     ----------
